//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Element/PolMatrices.h
//! @brief     Defines class PolarizerPair.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_BASE_ELEMENT_POLMATRICES_H
#define BORNAGAIN_BASE_ELEMENT_POLMATRICES_H

#include "Base/Spin/SpinMatrix.h"
#include "Base/Spin/Spinor.h"

//! Convenience class for handling polarization density matrix and polarization analyzer operator
//! @ingroup simulation

class PolMatrices {
public:
    PolMatrices();
    PolMatrices(SpinMatrix polarization, SpinMatrix analyzer);

    //! Sets the polarization density matrix (in spin basis along z-axis)
    void setPolarizerMatrix(const SpinMatrix& polarization) { m_polarizer_matrix = polarization; }

    //! Gets the polarization density matrix (in spin basis along z-axis)
    const SpinMatrix& polarizerMatrix() const { return m_polarizer_matrix; }

    //! Sets the polarization analyzer operator (in spin basis along z-axis)
    void setAnalyzerMatrix(const SpinMatrix& analyzer) { m_analyzer_matrix = analyzer; }

    //! Gets the polarization analyzer operator (in spin basis along z-axis)
    const SpinMatrix& analyzerMatrix() const { return m_analyzer_matrix; }

private:
    SpinMatrix m_polarizer_matrix; //!< polarization density matrix
    SpinMatrix m_analyzer_matrix;  //!< polarization analyzer operator
};

#endif // BORNAGAIN_BASE_ELEMENT_POLMATRICES_H
#endif // USER_API
