//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/CatDevice/BackgroundItemCatalog.h
//! @brief     Defines class BackgroundItemCatalog
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_CATDEVICE_BACKGROUNDITEMCATALOG_H
#define BORNAGAIN_GUI_MODEL_CATDEVICE_BACKGROUNDITEMCATALOG_H

#include <QString>
#include <QVector>

class BackgroundItem;

class BackgroundItemCatalog {
public:
    using CatalogedType = BackgroundItem;

    // Do not change the numbering! It is serialized!
    enum class Type : uint8_t { None = 0, Constant = 1, Poission = 2 };

    struct UiInfo {
        QString menuEntry;
        QString description;
    };

    //! Creates the item of the given type.
    static BackgroundItem* create(Type type);

    //! Available types of items.
    //!
    //! Contains also type "None".
    //! This list is sorted as expected in the UI (e.g. in combo box)
    static QVector<Type> types();

    //! UiInfo on the given type.
    static UiInfo uiInfo(Type t);

    //! Returns the enum type of the given item.
    static Type type(const BackgroundItem* item);
};

#endif // BORNAGAIN_GUI_MODEL_CATDEVICE_BACKGROUNDITEMCATALOG_H
