//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/CatDevice/DistributionItemCatalog.h
//! @brief     Defines class DistributionItemCatalog
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_CATDEVICE_DISTRIBUTIONITEMCATALOG_H
#define BORNAGAIN_GUI_MODEL_CATDEVICE_DISTRIBUTIONITEMCATALOG_H

#include <QString>
#include <QVector>

class DistributionItem;

class DistributionItemCatalog {
public:
    using CatalogedType = DistributionItem;

    // Do not change the numbering! It is serialized!
    enum class Type : uint8_t {
        None = 0,
        Gate = 1,
        Lorentz = 2,
        Gaussian = 3,
        LogNormal = 4,
        Cosine = 5,
        Trapezoid = 6
    };

    struct UiInfo {
        QString menuEntry;
        QString description;
        QString iconPath;
    };

    //! Creates the item of the given type.
    static DistributionItem* create(Type type);

    //! Available types of items.
    //!
    //! Contains also type "None".
    //! This list is sorted as expected in the UI (e.g. in combo box)
    static QVector<Type> types();

    //! Types of symmetric distributions
    //!
    //! Contains also type "None".
    //! This list is sorted as expected in the UI (e.g. in combo box)
    static QVector<Type> symmetricTypes();

    //! UiInfo on the given type.
    static UiInfo uiInfo(Type t);

    //! Returns the enum type of the given item.
    static Type type(const DistributionItem* item);
};

#endif // BORNAGAIN_GUI_MODEL_CATDEVICE_DISTRIBUTIONITEMCATALOG_H
