//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/CatSample/RotationItemCatalog.h
//! @brief     Defines class RotationItemCatalog
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_CATSAMPLE_ROTATIONITEMCATALOG_H
#define BORNAGAIN_GUI_MODEL_CATSAMPLE_ROTATIONITEMCATALOG_H

#include <QString>
#include <QVector>

class RotationItem;

class RotationItemCatalog {
public:
    using CatalogedType = RotationItem;

    // Do not change the numbering! It is serialized!
    enum class Type : uint8_t {
        None = 0,
        X = 1,
        Y = 2,
        Z = 3,
        Euler = 4,
    };

    struct UiInfo {
        QString menuEntry;
        QString description;
        QString iconPath;
    };

    //! Creates the item of the given type.
    //!
    //! If type is "None", a nullptr is returned.
    static RotationItem* create(Type type);

    //! Available types of interference items.
    //!
    //! Contains also type "None".
    //! This list is sorted as expected in the UI (e.g. in combo box)
    static QVector<Type> types();

    //! UiInfo on the given type.
    static UiInfo uiInfo(Type t);

    //! Returns the enum type of the given item.
    static Type type(const RotationItem* item);
};

#endif // BORNAGAIN_GUI_MODEL_CATSAMPLE_ROTATIONITEMCATALOG_H
