//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Device/Instrument.h
//! @brief     Defines class Instrument.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef USER_API
#ifndef BORNAGAIN_GUI_MODEL_DEVICE_INSTRUMENT_H
#define BORNAGAIN_GUI_MODEL_DEVICE_INSTRUMENT_H

#include <memory>

class Beam;
class IDetector;

//! Assembles beam, detector and their relative positions with respect to the sample.

class Instrument {
public:
    Instrument(const std::shared_ptr<Beam>& beam, const IDetector& detector);
    ~Instrument();

    const Beam* beam() const { return m_beam.get(); }
    const IDetector& detector() const { return *m_detector; }

protected:
    std::shared_ptr<Beam> m_beam;
    std::unique_ptr<IDetector> m_detector;
};

#endif // BORNAGAIN_GUI_MODEL_DEVICE_INSTRUMENT_H
#endif // USER_API
