//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Model/SessionXML.h
//! @brief     Defines reader and writer classes for SessionModel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_MODEL_SESSIONXML_H
#define BORNAGAIN_GUI_MODEL_MODEL_SESSIONXML_H

#include <QVariant>
#include <QXmlStreamWriter> // used in every including file
#include <heinz/Complex.h>
#include <heinz/Vectors3D.h>

class QXmlStreamReader;
class SessionItem;
class MessageService;
class QUuid;

namespace GUI::Session::XML {
constexpr const char* ItemMimeType{"application/org.bornagainproject.xml.item.z"};
constexpr const char* LinkMimeType{"application/org.bornagainproject.fittinglink"};
constexpr const char* InstrumentModelTag{"InstrumentModel"};
constexpr const char* JobModelTag{"JobModel"};
constexpr const char* RealModelTag{"RealModel"};
constexpr const char* ItemTag{"Item"};
constexpr const char* ModelTypeAttribute{"ModelType"};
constexpr const char* ParameterTag{"Parameter"};

void writeModel(QXmlStreamWriter* writer, SessionItem* modelRootItem);
void writeItemAndChildItems(QXmlStreamWriter* writer, const SessionItem* item);

void readItems(QXmlStreamReader* reader, SessionItem* parent, QString topTag = "",
               MessageService* messageService = nullptr, const QString endTag = "");
QString readProperty(QXmlStreamReader* reader, SessionItem* item);

SessionItem* readItemAndChildItems(QXmlStreamReader* reader, SessionItem* parent_item,
                                   const QString endTag);

SessionItem* copyItem(const SessionItem* item_to_copy, SessionItem* new_parent);

} // namespace GUI::Session::XML

#endif // BORNAGAIN_GUI_MODEL_MODEL_SESSIONXML_H
