//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/ItemWithParticles.cpp
//! @brief     Implements class ItemWithParticles
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Sample/ItemWithParticles.h"
#include "Base/Vector/RotMatrix.h"
#include "GUI/Support/XML/Serialize.h"
#include "Sample/Particle/IParticle.h"
#include "Sample/Scattering/Rotations.h"


ItemWithParticles::ItemWithParticles(const QString& abundanceTooltip,
                                     const QString& positionTooltip)
{
    m_abundance.init("Abundance", abundanceTooltip, 1.0, Unit::unitless, 3 /* decimals */,
                     RealLimits::limited(0.0, 1.0), "abundance");
    m_position.init("Position Offset", positionTooltip, Unit::nanometer, "pos");
    m_rotation.init("Rotation", "");
}

std::unique_ptr<IRotation> ItemWithParticles::createRotation() const
{
    if (!m_rotation.currentItem())
        return {};
    const auto matrix = m_rotation->rotation();
    return std::unique_ptr<IRotation>(IRotation::createRotation(matrix));
}
