//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/MaterialItems.h
//! @brief     Defines class MaterialItems
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_MATERIALITEMS_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_MATERIALITEMS_H

#include <QObject>
#include <QVector>

class MaterialItem;
class Streamer;

class MaterialItems : public QObject {
    Q_OBJECT

public:
    MaterialItems();
    ~MaterialItems();

    void clear();

    //! Add the material and take ownership of it.
    void addMaterial(MaterialItem* materialItem);

    MaterialItem* addRefractiveMaterial(const QString& name, double delta, double beta);
    MaterialItem* addSLDMaterial(const QString& name, double sld, double abs_term);

    MaterialItem* materialFromName(const QString& name) const;
    MaterialItem* materialFromIdentifier(const QString& identifier) const;

    //! Inserts a copy of the given material and returns the newly inserted item.
    //!
    //! The copy will have a different material identifier and a different name.
    MaterialItem* insertCopy(const MaterialItem& materialItem);

    const QVector<MaterialItem*>& materialItems() const;

    MaterialItem* defaultMaterial() const;

    void removeMaterial(MaterialItem* materialItem);

    void serialize(Streamer& s);

    //! Copies the complete content, emitting signals for existing and changed materials
    void initFrom(const MaterialItems& from);

signals:
    void materialAddedOrRemoved();
    void materialChanged(MaterialItem* materialItem);

private:
    //! Add the material and take ownership of it.
    //!
    //! In the given flag the signal "materialAddedOrRemoved" can be suppressed.
    void addMaterial(MaterialItem* material, bool signalAdding);

    QVector<MaterialItem*> m_materialItems; //!< all materials (owned by this class)
};

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_MATERIALITEMS_H
