//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/MultiLayerItem.h
//! @brief     Defines class MultiLayerItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_MULTILAYERITEM_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_MULTILAYERITEM_H

#include "GUI/Model/Descriptor/VectorProperty.h"
#include "GUI/Model/Sample/Item3D.h"
#include "GUI/Model/Sample/MaterialItems.h"
#include <QString>
#include <QUuid>
#include <QVector>

class ItemWithMaterial;
class LayerItem;
class QXmlStreamReader;
class QXmlStreamWriter;
class Streamer;

class MultiLayerItem : public virtual Item3D {
public:
    MultiLayerItem();

    void initFrom(const MultiLayerItem* other);

    QVector<ItemWithMaterial*> itemsWithMaterial() const;

    void addStandardMaterials();

    QString sampleName() const { return m_name; }
    void setSampleName(const QString& s) { m_name = s; }

    QString description() const { return m_description; }
    void setDescription(const QString& s) { m_description = s; }

    DoubleProperty& crossCorrLength() { return m_crossCorrelationLength; }
    const DoubleProperty& crossCorrLength() const { return m_crossCorrelationLength; }
    void setCrossCorLength(double d) { m_crossCorrelationLength.setValue(d); }

    VectorProperty& externalField() { return m_externalField; }
    const VectorProperty& externalField() const { return m_externalField; }
    void setExternalField(const R3& r) { m_externalField.setR3(r); }

    QVector<LayerItem*> layers() const;

    //! Creates and inserts a layer at given index.
    //!
    //! No properties etc. have been initialized; this has to be done by the caller.
    //! If index = -1, create a layer at the end of the list.
    LayerItem* addLayer(int index = -1);

    void removeLayer(LayerItem* item);
    void moveLayer(LayerItem* item, LayerItem* beforeThisLayer);

    void writeTo(QXmlStreamWriter* writer) const;
    void readFrom(QXmlStreamReader* reader);
    void serialize(Streamer& s);

    MaterialItems& materialItems() { return m_materials; }
    const MaterialItems& materialItems() const { return m_materials; }

private:
    QString m_name;
    QString m_description;
    DoubleProperty m_crossCorrelationLength;
    VectorProperty m_externalField;
    QVector<LayerItem*> m_layers;
    MaterialItems m_materials;
};

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_MULTILAYERITEM_H
