//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Import/RealDataPresenter.cpp
//! @brief     Implements class RealDataPresenter
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Import/RealDataPresenter.h"
#include "GUI/Util/Error.h"
#include "GUI/View/Import/RealDataMaskWidget.h"
#include "GUI/View/Import/SpecularDataImportWidget.h"
#include "GUI/View/Plot2D/IntensityDataWidget.h"
#include "GUI/View/PlotSpecular/SpecularDataWidget.h"
#include "GUI/View/Projection/IntensityDataProjectionsWidget.h"

RealDataPresenter::RealDataPresenter(QWidget* parent)
    : ItemComboWidget(parent)
{
    registerWidget("Heat Map", create_new<IntensityDataWidget>);
    registerWidget("Projections", create_new<IntensityDataProjectionsWidget>);
    registerWidget("Mask Editor", create_new<RealDataMaskWidget>);
    registerWidget("Reflectometry (Graph only)", create_new<SpecularDataWidget>);
    registerWidget("Reflectometry (Configuration)", create_new<SpecularDataImportWidget>);
}

QStringList RealDataPresenter::activePresentationList()
{
    ASSERT(realItem());

    QStringList result;
    if (realItem()->isIntensityData())
        result << "Heat Map"
               << "Projections"
               << "Mask Editor";
    else if (realItem()->isSpecularData()) {
        if (realItem()->dataLoader() != nullptr)
            result << "Reflectometry (Configuration)";
        result << "Reflectometry (Graph only)";
    } else
        throw Error("Error in RealDataPresenter::activePresentationList: unsupported data type");
    return result;
}
