//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/Icosahedron.cpp
//! @brief     Implements class Icosahedron.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Sample/HardParticle/Icosahedron.h"
#include <ff/Make.h>

Icosahedron::Icosahedron(const std::vector<double> P)
    : IFormFactorPolyhedron(P)
    , m_edge(m_P[0])
{
    validateOrThrow();
}

Icosahedron::Icosahedron(double edge)
    : Icosahedron(std::vector<double>{edge})
{
}

std::string Icosahedron::validate() const
{
    if (m_edge <= 0)
        return jointError({"nonpositive edge=" + std::to_string(m_edge)});

    pimpl.reset(ff::make::Icosahedron(m_edge));
    shift(0.7557613140761708 * m_edge);

    m_validated = true;
    return "";
}
