//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/Icosahedron.h
//! @brief     Defines class Icosahedron.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_ICOSAHEDRON_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_ICOSAHEDRON_H

#include "Sample/HardParticle/IFormFactorPolyhedron.h"

//! A regular icosahedron.
//! @ingroup hardParticle

class Icosahedron : public IFormFactorPolyhedron {
public:
    Icosahedron(double edge);
#ifndef USER_API
    Icosahedron(std::vector<double> P);

    Icosahedron* clone() const override
    {
        return new Icosahedron(m_edge);
    }
    std::string className() const final
    {
        return "Icosahedron";
    }
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"Edge", "nm"}};
    }

    double edge() const
    {
        return m_edge;
    }

    std::string validate() const override;

private:
    static const ff::Topology topology;
    const double& m_edge;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_ICOSAHEDRON_H
