//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/PlatonicTetrahedron.h
//! @brief     Defines class PlatonicTetrahedron
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_PLATONICTETRAHEDRON_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_PLATONICTETRAHEDRON_H

#include "Sample/HardParticle/IFormFactorPolyhedron.h"

//! A frustum with equilateral trigonal base.
//! @ingroup hardParticle

class PlatonicTetrahedron : public IFormFactorPolyhedron {
public:
    PlatonicTetrahedron(double edge);
#ifndef USER_API
    PlatonicTetrahedron(std::vector<double> P);

    PlatonicTetrahedron* clone() const override
    {
        return new PlatonicTetrahedron(m_edge);
    }
    std::string className() const final
    {
        return "PlatonicTetrahedron";
    }
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"Edge", "nm"}};
    }

    double edge() const
    {
        return m_edge;
    }
    double height() const
    {
        return sqrt(2. / 3) * m_edge;
    }

    std::string validate() const override;

private:
    static const ff::Topology topology;
    const double& m_edge;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_PLATONICTETRAHEDRON_H
