//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/Prism3.h
//! @brief     Defines class Prism3.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_PRISM3_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_PRISM3_H

#include "Sample/HardParticle/IFormFactorPrism.h"

//! A prism based on an equilateral triangle.
//! @ingroup hardParticle

class Prism3 : public IFormFactorPrism {
public:
    Prism3(double base_edge, double height);
#ifndef USER_API
    Prism3(std::vector<double> P);

    Prism3* clone() const override
    {
        return new Prism3(m_base_edge, m_height);
    }
    std::string className() const final
    {
        return "Prism3";
    }
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"BaseEdge", "nm"}, {"Height", "nm"}};
    }

    double baseEdge() const
    {
        return m_base_edge;
    }
    double height() const override
    {
        return m_height;
    }

    std::string validate() const override;

private:
    const double& m_base_edge;
    const double& m_height;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_PRISM3_H
