//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/Pyramid3.h
//! @brief     Defines class Pyramid3
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_PYRAMID3_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_PYRAMID3_H

#include "Sample/HardParticle/IFormFactorPolyhedron.h"

//! A frustum with equilateral trigonal base.
//! @ingroup hardParticle

class Pyramid3 : public IFormFactorPolyhedron {
public:
    Pyramid3(double base_edge, double height, double alpha);
#ifndef USER_API
    Pyramid3(std::vector<double> P);

    Pyramid3* clone() const override
    {
        return new Pyramid3(m_base_edge, m_height, m_alpha);
    }
    std::string className() const final
    {
        return "Pyramid3";
    }
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"BaseEdge", "nm"}, {"Height", "nm"}, {"Alpha", "rad"}};
    }

    double baseEdge() const
    {
        return m_base_edge;
    }
    double height() const
    {
        return m_height;
    }
    double alpha() const
    {
        return m_alpha;
    }
    std::string validate() const override;

private:
    static const ff::Topology topology;
    const double& m_base_edge;
    const double& m_height;
    const double& m_alpha;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_PYRAMID3_H
